@@ -164,11 +164,11 @@ if ($do==1) {
       my $sleep=0;
       while (1==1) {
         my $ls_output=$handle->cmd("ls -1");
-        last if -1<index $ls_output,'config/applicationHost.config';
+        last if -1<index $ls_output,'appcmd.exe';
         sleep 2;
         last if $sleep++>300;
       }
-      sleep 2;
+      sleep 5;
       ($stdout,$stderr)=$handle->cmd("./appcmd add site /name:FullAutoAPI ".
          "/id:2 /physicalPath:$cyglocwf\\root /bindings:http/*:4000",
          '__display__');
